<?php

class Parser extends MY_Controller {

	var $temp_uri;
	var $view;
	var $segments = array();
	var $segment_count = 0, $result_count = 0;

	var $breadcrumb_links = array(), $matches = array();
	var $ancestry = array();
	var $page = 1;
	var $media_view = FALSE;
	var $home = FALSE;

	var $parent_title;
	
	function Parser()
	{
		parent::MY_Controller();

		$this->load->model('Content_model');
		$this->load->model('File_model');
		$this->load->model('User_model');
		$this->load->helper(array('url', 'image'));

		$this->data['mime_types'] = $this->File_model->mime_types;
		$this->data['image_types'] = $this->File_model->image_types;
		$this->data['playable_types'] = $this->File_model->playable_types;

		$this->Content_model->list_langs();
	}
	
    function index()
    {
		$this->data['parents'] = array();

		$this->Content_model->link_mode = 0;
		$this->Content_model->lang_mode = $this->Content_model->lang_count;

		// get all parameters from uri
		$this->_parse_uri();

		switch($this->segment_count)
		{
		
		case 0:
			// no segments - do home page
			$this->_home();
			break;
		
		case 1:
			$this->Content_model->temp_value = $this->segments[0];
			$this->Content_model->temp_id = '';
			$results = $this->Content_model->find_by_uri();

			if($results)
			{
	
				$this->Content_model->content_id = $results[0]['content_id'];
				$this->Content_model->user_id = $results[0]['user_id'];
				$this->Content_model->parent_id = $results[0]['parent_id'];
				$this->Content_model->type_id = $results[0]['type_id'];
				$this->Content_model->type_uri_name = $results[0]['type_uri_name'];
				$this->Content_model->date_created = $results[0]['date_created'];
				$this->Content_model->date_end_expiry = $results[0]['date_end_expiry'];
				$this->Content_model->date_updated = $results[0]['date_updated'];
				$this->Content_model->publish = $results[0]['publish'];
				$this->Content_model->title_id = $results[0]['title_id'];
				$this->Content_model->title = $results[0]['title'];
				$this->Content_model->subtitle = $results[0]['subtitle'];
				$this->Content_model->uri_title = $results[0]['uri_title'];
				$this->Content_model->keywords = $results[0]['keywords'];
				$this->Content_model->title_updated = $results[0]['title_updated'];
			
				// prepare breadcrumbs
				$this->temp_uri .= '/'.$results[0]['uri_title'];
				$this->breadcrumb_links[] = anchor('', $this->cms_labels['home']);
				$this->breadcrumb_links[] = anchor($this->temp_uri, $results[0]['title']);

				// load metadata
				$this->Content_model->temp_id = $results[0]['type_id'];
				$this->Content_model->scope = 'types';
				
				$this->Content_model->list_fields_related();
				$this->Content_model->scope = 'content';
				$this->Content_model->temp_id = $this->Content_model->content_id;
				$this->Content_model->load_metadata();

				$this->_prepare_view();

			}
			else
			{
				$this->output->set_status_header('404');
				$this->data['header'] = $this->cms_labels['server_error_404_header'];
				$html = "<p>".sprintf($this->cms_labels['server_error_404_message'],implode('/',$this->segments))."</p>";
				$html .= "<p>".$this->cms_labels['server_error_404_suggest']."</p>";
				$html .= '<p>'.anchor('',$this->cms_labels['home'])."</p>";

				$this->data['message'] = $html;
				$this->view = 'themes/'.$this->Site_model->theme.'/error_404';
			}

			break;
		
		default:
			// if site preferences specify a vaild home page ID, then omit home page from menu
			if($this->Site_model->home_content_id > 0)
			{
				$this->Content_model->content_id = $this->Site_model->home_content_id;
				$this->Content_model->omit_id = $this->Site_model->home_content_id;
				
				if($this->Content_model->content_exists() === TRUE)
				{
					$this->Content_model->omit_id = $this->Site_model->home_content_id;
				}

			}

			if($this->_find_content())
			{
				$this->_prepare_view();
			}
			else
			{
				$this->output->set_status_header('404');
				$this->data['header'] = $this->cms_labels['server_error_404_header'];

				$html = "<p>".sprintf($this->cms_labels['server_error_404_message'],implode('/',$this->segments))."</p>";
				if(count($this->matches) > 0)
				{
					$html .= "<p>{$this->cms_labels['server_error_404_matches']}</p>\r";
					$html .= ul($this->matches);
				}
				$html .= "<p>".$this->cms_labels['server_error_404_suggest']."</p>";
				$html .= '<p>'.anchor('',$this->cms_labels['home'])."</p>";
				
				$this->data['message'] = $html;

				$this->view = 'themes/'.$this->Site_model->theme.'/error_404';
			}

			break;
		}

		$this->data['resource_uri'] = $this->temp_uri;
		$zz = explode('/',trim($this->temp_uri,'/'));
		array_pop($zz);
		array_pop($zz);
		$this->data['parent_uri'] = implode('/',$zz);

		if(is_array($this->breadcrumb_links) && count($this->breadcrumb_links) > 0)
		{
			$this->data['breadcrumb_links'] = $this->breadcrumb_links;
		}
		
		$header_view = 'themes/'.$this->Site_model->theme.'/inc_header';
		if($this->media_view)
		{
			$header_view .= '_media';
		}

		$header_view_full = APPPATH.'views/'.$header_view.'.php';
		if(file_exists($header_view_full))
		{
			$this->data['html_header'] = $this->load->view($header_view,$this->data,TRUE);
		}

		$view_full = APPPATH.'views/'.$this->view.'.php';
		if(!file_exists($view_full))
		{
			$this->view = 'display';
		}
				
		$this->load->view($this->view,$this->data);		

    }

	function _parse_uri()
	{

		$uri_segments = array();
		$uri_array = $this->uri->segment_array();

		$params = array('page' => '','lang' => '','date' => '','media'  => '');
		$patterns = array(
		'lang' => '#^([a-z]{3})$#',
		'date' => '#^([0-9]{4}-[0-9]{2}-[0-9]{2}|[0-9]{4}-[0-9]{2}|[0-9]{4})$#',
		'page' => '#^p([0-9]+)$#',
		'media' => '#^view$#',
		);

		$segment_count = count($uri_array);
		$segment_current = 1;
		$tmp_segments = $uri_array;
		
		foreach($uri_array as $index => $segment)
		{
			$match = FALSE;
			foreach($patterns as $key => $pattern)
			{
				if(preg_match($pattern,$segment) && $params[$key] == '')
				{
					if($key == 'page')
					{
						if($segment_current == $segment_count)
						{
							$params[$key] = str_replace('p','',$segment);
							$match = TRUE;
							break;
						
						}
					}
					else if($key == 'media')
					{
						$media_segments = array_slice($tmp_segments, $index);
						$params[$key] = '/'.implode('/',$media_segments);
						$match = TRUE;
						break;
						
					}
					else if($key == 'lang')
					{
						$this->Content_model->temp_lang = $segment;
						if($this->Content_model->lang_load())
						{
							$params[$key] = $segment;
							$match = TRUE;
						}
						else
						{
							$this->Content_model->temp_lang = $this->Site_model->site_default_lang;
						}
						
					}
					else
					{
						$params[$key] = $segment;
						$match = TRUE;
						break;
					}
					
				}
	
			}

			if(!$match && $params['media'] == '')
			{
				$uri_segments[] = $segment;
			}
			$segment_current += 1;

		}

		$this->segments = $uri_segments;
		$this->segment_count = count($this->segments);

		if($params['date'] != '')
		{
			$this->Content_model->date_filter = $params['date'];
		}

		if($params['lang'] == '')
		{
			$params['lang'] = $this->Site_model->site_default_lang;
		}
		$this->Site_model->temp_lang = $params['lang'];
		$this->Content_model->temp_lang = $params['lang'];
		$this->_load_cms_labels();
		$this->_load_site_metadata();

		if($params['page'] != '')
		{
			$this->page = $params['page'];
			$this->Content_model->page = $params['page'];
		}
		
		if($params['media'] != '')
		{
			$this->File_model->temp_lang = $this->Content_model->temp_lang;
			$this->File_model->file_uri = $params['media'];
			$this->media_view = $this->File_model->find_media_by_uri(TRUE);
		}
		
	}
	
	function _find_content()
	{

		$msg = '';
		
		$tree = array();


		foreach($this->segments as $index => $uri_segment)
		{
			$this->Content_model->reset_vars();
			$this->Content_model->temp_value = $uri_segment;
			$info = $this->Content_model->find_by_uri();
			
			if($info)
			{
				$this->Content_model->temp_id = $info[0]['content_id'];
				$tree[$index] = $info[0];
			}

		}

		$this->result_count = count($tree);

		$last_index = $this->result_count - 1;
		$this->temp_uri = '';
		
		if($this->result_count > 0 && $this->result_count == $this->segment_count)
		{
			// create parent hierarchy
			$parents = $tree;

			// create breadcrumb links
			$this->breadcrumb_links = array(anchor($this->temp_uri,$this->cms_labels['home']));

			foreach($tree as $index => $vals)
			{
				if(is_array($vals))
				{
					$this->Content_model->content_id = $vals['content_id'];
					$this->Content_model->user_id = $vals['user_id'];
					$this->Content_model->parent_id = $vals['parent_id'];
					$this->Content_model->type_id = $vals['type_id'];
					$this->Content_model->type_uri_name = $vals['type_uri_name'];
					$this->Content_model->date_created = $vals['date_created'];
					$this->Content_model->date_end_expiry = $vals['date_end_expiry'];
					$this->Content_model->date_updated = $vals['date_updated'];
					$this->Content_model->publish = $vals['publish'];
					$this->Content_model->title_id = $vals['title_id'];
					$this->Content_model->title = $vals['title'];
					$this->Content_model->subtitle = $vals['subtitle'];
					$this->Content_model->uri_title = $vals['uri_title'];
					$this->Content_model->keywords = $vals['keywords'];
					$this->Content_model->title_updated = $vals['title_updated'];
		
					$this->Content_model->temp_id = $vals['content_id'];
					$this->temp_uri = $this->Content_model->generate_uri();
					$parents[$index]['uri'] = $this->temp_uri;
					
					if($index < $last_index)
					{
						$this->breadcrumb_links[] = anchor($this->temp_uri, $vals['title']);
						$this->parent_title = $vals['title'];
					}
					else
					{
						$this->breadcrumb_links[] = $vals['title'];
					}

				}
			}

			array_pop($parents);
			$parents = array_reverse($parents);
			$this->data['parents'] = $parents;

		}
		else
		{

			if($this->result_count > 0 )
			{
				// generate possible matches or parent list
				
				foreach($tree as $index => $vals)
				{
					if(is_array($vals))
					{
						$this->Content_model->temp_id = $vals['content_id'];
						$this->temp_uri = $this->Content_model->generate_uri();

						$this->matches[] = anchor($this->temp_uri, $vals['title']);
			
					}
				}

			}
			
			return FALSE;

		}

			return true;

	}

	function _prepare_view()
	{
		// if user logged in, pass session values to view
		$this->load->library('session');
		if($this->session->userdata('user_id'))
		{
			$this->data['userdata'] = $this->session->userdata;
		}
				
		// initialize content array
		$content_vars = array();

		// load author user data

		$this->User_model->temp_id = $this->Content_model->user_id;
		$this->User_model->load_user();
		if($this->User_model->name_first != '')
		{
			$content_vars['author'] = array(
			'name_first' => $this->User_model->name_first,
			'name_last' => $this->User_model->name_last,
			'username' => $this->User_model->username,
			'email' => $this->User_model->email
			);
		}

		// load data for view
		$this->Content_model->temp_id = $this->Content_model->type_id;
		$this->Content_model->scope = 'content';
		$this->Content_model->load_type();
		$this->view = 'themes/'.$this->Site_model->theme.'/'.$this->Content_model->type_uri_name;

		// see if we are viewing attached media, and if so, load media info and switch to 'media' view
		if($this->media_view)
		{
			$this->view = 'themes/'.$this->Site_model->theme.'/media';
			$this->breadcrumb_links[] = $this->File_model->title;

			$mime_cat = preg_replace('#^([a-z]+)/(.*)$#','$1',$this->File_model->mime_type);
			$media_vars = array(
			'media_id' => $this->File_model->media_id,
			'file_uri' => $this->File_model->file_uri,
			'filename' => basename($this->File_model->file_uri),
			'external' => $this->File_model->external,
			'mime_type' => $this->File_model->mime_type,
			'mime_cat' => $mime_cat,
			'date_created' => $this->File_model->date_created,
			'publish' => $this->File_model->publish,
			'title_id' => $this->File_model->title_id,
			'title_rel_id' => $this->File_model->title_rel_id,
			'title' => $this->File_model->title,
			'uri_title' => $this->File_model->uri_title,
			'title_updated' => $this->File_model->title_updated,
			);
			if($this->File_model->keywords != '') {
				$media_vars['keywords'] = $this->File_model->keywords;
				$media_vars['keyword_links'] = $this->File_model->keyword_links();
			}
			if($this->File_model->external == 0) {
				$media_vars['rel_path'] = MEDIA_PATH_ORIG.$this->File_model->file_uri;
				$fp = ROOT_REL.$media_vars['rel_path'];
				$media_vars['server_path'] = $fp;

				$size = filesize($fp);
				$this->File_model->lang_load();
				$this->lang->load('mime', $this->File_model->lang_CI_Name);
				$byte_labels = $this->lang->line('file_size_abbr');
				$size_formatted = resize_bytes_lang($size,$byte_labels);
				
				$media_vars['size_bytes'] = $size;
				$media_vars['size_formatted'] = $size_formatted;
			}
			if($this->File_model->subtitle != '') {
				$media_vars['subtitle'] = $this->File_model->subtitle;
			}

			$this->File_model->load_metadata();

			$m_meta = $this->File_model->metadata;
			
			foreach($m_meta as $id => $field) {
				$media_vars[$field['field_ref_name']] = $field['value'];
				
				if($field['date_updated'] > $this->File_model->date_updated) {
					$this->File_model->date_updated = $field['date_updated'];
				}
	
			}

			$media_vars['date_updated'] = convert_time($this->File_model->date_updated, $this->Site_model->site_timezone);
			$media_vars['date_updated_W3C'] = convert_time($this->File_model->date_updated, $this->Site_model->site_timezone, "Y-m-d");

			$this->data['media'] = $media_vars;
			// end media view setup
		}

		// get this resource's URI
		$this->Content_model->temp_id = $this->Content_model->content_id;
		$this->temp_uri = $this->Content_model->generate_uri();

		$content_vars['content_id'] = $this->Content_model->content_id;
		$content_vars['parent_id'] = $this->Content_model->parent_id;
		$content_vars['type_id'] = $this->Content_model->type_id;

		$content_vars['type_uri_name'] = $this->Content_model->type_uri_name;
		$content_vars['title'] = $this->Content_model->title;
		if($this->Content_model->subtitle != '') {
			$content_vars['subtitle'] = $this->Content_model->subtitle;
		}

		if($this->Content_model->keywords != '') {
			$content_vars['keywords'] = $this->Content_model->keywords;
			$content_vars['keyword_links'] = $this->Content_model->keyword_links();
		}

		$content_vars['date_created'] = convert_time($this->Content_model->date_created, $this->Site_model->site_timezone);
		$content_vars['date_created_W3C'] = convert_time($this->Content_model->date_created, $this->Site_model->site_timezone, "Y-m-d");

		if($this->Content_model->date_end_expiry != '0000-00-00 00:00:00')
		{
			$content_vars['date_expiry'] = convert_time($this->Content_model->date_end_expiry, $this->Site_model->site_timezone,DATE_RFC1123);
			$content_vars['date_expiry_RFC850'] = convert_time($this->Content_model->date_end_expiry, 'UTC',DATE_RFC850);
		}

		$this->Content_model->temp_id = $this->Content_model->type_id;
		$this->Content_model->scope = 'types';
		$this->Content_model->list_fields_related();

		$this->Content_model->scope = 'content';
		$this->Content_model->temp_id = $this->Content_model->content_id;
		$this->Content_model->load_metadata();

		$c_meta = $this->Content_model->metadata;
		
		foreach($c_meta as $id => $field) {
			$content_vars[$field['field_ref_name']] = $field['value'];
			
			if($field['date_updated'] > $this->Content_model->date_updated) {
				$this->Content_model->date_updated = $field['date_updated'];
			}

			if($field['field_input_type'] == 'directory') {
				
				$dir = ROOT_REL.MEDIA_PATH_ORIG.$field['value'];

				$this->File_model->temp_lang = $this->Content_model->temp_lang;
				$this->File_model->lang_load();
				$this->File_model->dir_current = $dir;
				$this->File_model->list_files(FALSE,TRUE,TRUE);
				$content_vars['dir_listing'] = $this->File_model->file_list;
				$content_vars['subdirs'] = $this->File_model->dir_list;
			}

		}

		$content_vars['date_updated'] = convert_time($this->Content_model->date_updated, $this->Site_model->site_timezone);
		$content_vars['date_updated_W3C'] = convert_time($this->Content_model->date_updated, $this->Site_model->site_timezone, "Y-m-d");

		$this->Content_model->lang_load();
		$content_vars['lang_ISO_639_3'] = $this->Content_model->lang_ISO_639_3;

		$this->data['content'] = $content_vars;

		// list attachments
		$this->_attachment_info();

		// build menu array
		if($this->Content_model->parent_id == 0)
		{
			$menu_title = $this->Site_model->title;
		}
		else
		{
			$menu_title = $this->parent_title;
		}

		$this->data['menu_title'] = $menu_title;

		$this->Content_model->temp_lang = $this->Content_model->lang_ISO_639_3;
		$this->Content_model->type_id = '';
		$this->Content_model->limit = '';

		$menu = $this->Content_model->get_children(true,true);
		$this->data['menu'] = $menu;

		// children
		$this->Content_model->parent_id = $content_vars['content_id'];
		$this->Content_model->page = $this->page;
		$this->Content_model->limit = $this->Site_model->limit_posts;
		$children = $this->Content_model->get_children(false,true);

		foreach($children as $index => $entry)
		{
			// load author user data
			$this->User_model->temp_id = $entry['user_id'];
			$this->User_model->load_user();
			if($this->User_model->name_first != '')
			{
				$children[$index]['author'] = array(
				'name_first' => $this->User_model->name_first,
				'name_last' => $this->User_model->name_last,
				'username' => $this->User_model->username,
				'email' => $this->User_model->email
				);
			}
		}
		$this->data['children'] = $children;
		$this->data['total_children'] = $this->Content_model->content_count;
		$this->data['page'] = $this->Content_model->page;
		$this->data['limit'] = $this->Content_model->limit;
		
		// number of pages
		$this->data['pages'] = ceil($this->Content_model->content_count / $this->Content_model->limit);
		$this->load->library('pagination');
		
		// recently added children
		if($this->page > 1)
		{
			$this->Content_model->page = 1;
			$recent = $this->Content_model->get_children(false,true);
		}
		else
		{
			$recent = $children;
		}
		$this->data['recent'] = $recent;

		// see if there are other languages for this content
		$other_langs = $this->Content_model->get_other_lang_ids();
		if($other_langs)
		{
			$this->data['other_langs'] = $other_langs;
		}
		
		// get top-level menu
		$this->Content_model->reset_vars();
		$top_menu = $this->Content_model->get_descendant_content(0,FALSE);
		$this->data['top_menu'] = $top_menu;
	}

	function _home()
	{
		$this->home = TRUE;
		// if site preferences specify a vaild home page ID, then redirect and omit home page from menu, otherwise auto-generate home page
		if($this->Site_model->home_content_id > 0)
		{
			$this->Content_model->content_id = $this->Site_model->home_content_id;
			$this->Content_model->omit_id = $this->Site_model->home_content_id;
			
			if($this->Content_model->content_exists())
			{
				$this->Content_model->load_content();
				$this->_prepare_view();
				$this->home = FALSE;
			}
		}
			
		if($this->home)
		{
			$this->view = 'themes/'.$this->Site_model->theme.'/home';
			$menu = $this->Content_model->get_descendant_content();
			$this->data['menu'] = $menu;
	
			$this->data['breadcrumb_links'] = array($this->cms_labels['home']);
			
			// recently added content
			$this->Content_model->reset_vars();
			$this->Content_model->limit = $this->Site_model->limit_posts;
			$this->data['recent'] = $this->_recent();
		}

	}

	function _recent($parent=NULL)
	{
		$this->Content_model->list_types();
		if($this->home)
		{
			$this->Content_model->omit_types = $this->Content_model->omit_types_home;
		}
		if(isset($parent))
		{
			$this->Content_model->parent_id = $parent;
		}
		$this->Content_model->list_content(TRUE);

		$recent = $this->Content_model->content_list;
		$recent_entries = array();

		
		if(count($recent) > 0)
		{
			foreach($recent as $index => $post)
			{
				$entry = array(
				'content_id' => $post['content_id'],
				'user_id' => $post['user_id'],
				'parent_id' => $post['parent_id'],
				'type_id' => $post['type_id'],
				'type_uri_name' => $post['type_uri_name'],
				'type_label' => $post['type_label'],
				'title_id' => $post['title_id'],
				'title' => $post['title'],
				'uri_title' => $post['uri_title'],
				'subtitle' => $post['subtitle'],
				'keywords' => $post['keywords'],
				'lang_ISO_639_3' => $post['lang_ISO_639_3']
				);

				// get author info
				$this->User_model->temp_id = $post['user_id'];
				if($this->User_model->load_user())
				{
					$entry['author'] = array(
					'name_first' => $this->User_model->name_first,
					'name_last' => $this->User_model->name_last,
					'username' => $this->User_model->username,
					'email' => $this->User_model->email
					);
				}

				$entry['date_created'] = convert_time($post['date_created'], $this->Site_model->site_timezone);
	
				$date_updated = $post['date_updated'];

				if($post['date_end_expiry'] != '0000-00-00 00:00:00')
				{
					$entry['date_end_expiry'] = convert_time($post['date_end_expiry'], $this->Site_model->site_timezone);
				}
	
				foreach($post['metadata'] as $id => $field) {
				
					if(array_key_exists('field_ref_name',$field))
					{
						$tmp_field_name = $field['field_ref_name'];
					}
					else
					{
						$this->Content_model->temp_id = $id;
						$this->Content_model->load_field();
						$tmp_field_name = $this->Content_model->field_ref_name;;
					}
		
					$entry[$tmp_field_name] = encode_entities($field['value']);
					
					if($field['date_updated'] > $date_updated) {
						$date_updated = $field['date_updated'];
					}
		
				}
	
				$entry['date_updated'] = convert_time($date_updated, $this->Site_model->site_timezone);
				
				// keyword links
				if($post['keywords']  != '') {
					$this->Content_model->keywords = $post['keywords'];
					$entry['keyword_links'] = $this->Content_model->keyword_links();
				}

				// get uri of content
				$this->Content_model->scope = 'content';
				$this->Content_model->temp_id = $post['content_id'];
				$this->Content_model->temp_lang = $post['lang_ISO_639_3'];
				$entry['uri'] = $this->Content_model->generate_uri();
				
				$recent_entries[] = $entry;
				$this->Content_model->reset_vars();
			
			}
		}

		return $recent_entries;

	}
	
	function _attachment_info()
	{

		// load mime type labels
		$this->lang->load('mime', $this->Content_model->lang_CI_Name);
		$this->data['mime_labels'] = $this->lang->line('mime');

		$this->Content_model->list_attachments();
		if(count($this->Content_model->attachments) > 0)
		{
			$attachments = array();

			foreach($this->Content_model->attachments as $media)
			{
				$this->File_model->reset_media_vars();
				$tmp_array = $media;
				$this->File_model->temp_id = $media['media_id'];
				$this->File_model->load_media();
				$tmp_array['file_uri'] = $this->File_model->file_uri;
				$tmp_array['external'] = $this->File_model->external;
				$tmp_array['mime_type'] = $this->File_model->mime_type;
				$tmp_array['mime_cat'] = preg_replace('#^([a-z]+)/(.*)$#','$1',$this->File_model->mime_type);
				$tmp_array['extension'] = strtolower(preg_replace('#^(.*)\.([a-zA-Z0-9]+)$#','$2',$this->File_model->file_uri));
				$tmp_array['filename'] = basename($this->File_model->file_uri);

				$tmp_array['date_created'] = $this->File_model->date_created;
				$tmp_array['publish'] = $this->File_model->publish;
				$this->File_model->temp_lang = $this->Content_model->temp_lang;
				$this->File_model->load_title();
				$tmp_array['title'] = $this->File_model->title;
				$tmp_array['uri_title'] = $this->File_model->uri_title;
				$tmp_array['subtitle'] = $this->File_model->subtitle;
				$tmp_array['keywords'] = $this->File_model->keywords;

				if($this->File_model->external == 0)
				{
					$tmp_array['path_basename'] = ROOT_REL.MEDIA_PATH_ORIG.basename($this->File_model->file_uri);
					$tmp_array['server_path'] = ROOT_REL.MEDIA_PATH_ORIG.$this->File_model->file_uri;
					$tmp_array['server_directory'] = ROOT_REL.MEDIA_PATH_ORIG.dirname($this->File_model->file_uri);
				}

				$this->File_model->scope = 'media';
				$this->File_model->temp_lang = $this->Content_model->temp_lang;
				$this->File_model->temp_id = $media['media_id'];
				$this->File_model->load_metadata();
				$file_meta = $this->File_model->metadata;
				if(count($file_meta) > 0)
				{
					foreach($file_meta as $file_info)
					{
						if($file_info['value'] != '')
						{
							$tmp_array[$file_info['field_ref_name']] = $file_info['value'];
						}
					}
				}

				$attachments[$this->File_model->file_uri] = $tmp_array;
				unset($tmp_array);
			}
			$this->data['attachments'] = $attachments;
		}
	}

}
?>
